Processor.App.ArticleUtils.article\_extractor.ArticleExtractor.custom\_filter\_raw
==================================================================================

.. currentmodule:: Processor.App.ArticleUtils.article_extractor

.. automethod:: ArticleExtractor.custom_filter_raw